translate.storage.trados.TradosSoup

Package translate :: Package storage :: Module trados :: Class TradosSoup |
[hide private]
[frames] | no frames]

# Class TradosSoup

source code

Class Variables | [hide private]
| MARKUP_MASSAGE = `[(re.compile('<(?P<fulltag>(?P<tag>[^\s\/]+).`...``

Class Variable Details | [hide private]

  ### MARKUP_MASSAGE Value:
      [(re.compile('<(?P<fulltag>(?P<tag>[^\s\/]+).*?)>(?P<content>.+)\r'),
      lambda x: '<%(fulltag)s>%(content)s</%(tag)s>' % x.groupdict()),]